@@ -3,10 +3,16 @@ import os
 from google.cloud import pubsub_v1
 
 
-def publish_debug_logs(message, publisher, environment_suffix):
+def publish_debug_logs(
+    message, publisher, environment_suffix, cloud_function
+):
+
+    if message.get("content"):
+        message["content"]["cloud_function"] = cloud_function
+
     payload = {
         "webhook_event": "DebugLogsGenerated",
-        "content": message
+        "content": message,
     }
 
     data = json.dumps(payload).encode("utf-8")
